Crate rasi_syscall

Crate rasi_syscall 

Modules

path
Cross-platform path manipulation that port from async_std::path

Structs

FileOpenModefs
A bitmask for open file.
Handle
A transparent type pointer that represents any implementation-related asynchronous system type.

Enums

CancelablePoll
The returns type of WouldBlock operations.

Traits

Executorexecutor
Future task system call interface.
FileSystemfs
Filesystem-related system call interface
Networknet
Network-related system call interface
Timertime
Timer-related system call interface

Functions

global_executorexecutor
Get the globally registered instance of Executor.
global_filesystemfs
Get the globally registered instance of FileSystem.
global_networknet
Get the globally registered instance of Network.
global_timertime
Get the globally registered instance of Timer.
ready
Create a ready status of CancelablePoll from F: FnOnce() -> T.
register_global_executorexecutor
Register provided Executor as global executor implementation.
register_global_filesystemfs
Register provided FileSystem as global filesystem implementation.
register_global_networknet
Register provided Network as global network implementation.
register_global_timertime
Register provided Timer as global timer implementation.
syscall_block_onexecutor
Run a future to completion on the current thread.
syscall_spawnexecutor
Spawns a task that polls the given future with output () to completion.