Modules
- path
- Cross-platform path manipulation that port from
async_std::path
Structs
- File
Open Mode fs - A bitmask for open file.
- Handle
- A transparent type pointer that represents any implementation-related asynchronous system type.
Enums
- Cancelable
Poll - The returns type of
WouldBlockoperations.
Traits
- Executor
executor - Future task system call interface.
- File
System fs - Filesystem-related system call interface
- Network
net - Network-related system call interface
- Timer
time - Timer-related system call interface
Functions
- global_
executor executor - Get the globally registered instance of
Executor. - global_
filesystem fs - Get the globally registered instance of
FileSystem. - global_
network net - Get the globally registered instance of
Network. - global_
timer time - Get the globally registered instance of
Timer. - ready
- Create a ready status of
CancelablePollfromF: FnOnce() -> T. - register_
global_ executor executor - Register provided
Executoras global executor implementation. - register_
global_ filesystem fs - Register provided
FileSystemas global filesystem implementation. - register_
global_ network net - Register provided
Networkas global network implementation. - register_
global_ timer time - Register provided
Timeras global timer implementation. - syscall_
block_ on executor - Run a future to completion on the current thread.
- syscall_
spawn executor - Spawns a task that polls the given future with output () to completion.